Crate git_sshripped_repository

Crate git_sshripped_repository 

Functions

agent_wrap_dir
Directory for agent-wrapped key files inside the git common directory.
agent_wrap_file
Path to an agent-wrapped key file for a given fingerprint.
github_sources_file
install_git_filters
Install Git filter and diff configuration.
install_gitattributes
Append filter/diff attribute lines to .gitattributes for the given patterns.
list_agent_wrap_files
List all agent-wrap .toml files in the agent-wrap directory.
local_config_file
manifest_file
metadata_dir
parse_agent_wrap
Parse an agent-wrapped key from a TOML string.
read_agent_wrap
Read an agent-wrapped key file, returning None if the file does not exist.
read_github_sources
Read the GitHub source registry, returning a default if the file does not exist.
read_local_config
Read the local repository config, returning a default if the file does not exist.
read_manifest
Read the repository manifest from .git-sshripped/manifest.toml.
write_agent_wrap
Write an agent-wrapped key file.
write_github_sources
Write the GitHub source registry to .git-sshripped/github-sources.toml.
write_local_config
Write the local repository config to .git-sshripped/config.toml.
write_manifest
Write the repository manifest to .git-sshripped/manifest.toml.