Functions
- agent_
wrap_ dir - Directory for agent-wrapped key files inside the git common directory.
- agent_
wrap_ file - Path to an agent-wrapped key file for a given fingerprint.
- github_
sources_ file - install_
git_ filters - Install Git filter and diff configuration.
- install_
gitattributes - Append filter/diff attribute lines to
.gitattributesfor the given patterns. - list_
agent_ wrap_ files - List all agent-wrap
.tomlfiles in the agent-wrap directory. - local_
config_ file - manifest_
file - metadata_
dir - parse_
agent_ wrap - Parse an agent-wrapped key from a TOML string.
- read_
agent_ wrap - Read an agent-wrapped key file, returning
Noneif the file does not exist. - read_
github_ sources - Read the GitHub source registry, returning a default if the file does not exist.
- read_
local_ config - Read the local repository config, returning a default if the file does not exist.
- read_
manifest - Read the repository manifest from
.git-sshripped/manifest.toml. - write_
agent_ wrap - Write an agent-wrapped key file.
- write_
github_ sources - Write the GitHub source registry to
.git-sshripped/github-sources.toml. - write_
local_ config - Write the local repository config to
.git-sshripped/config.toml. - write_
manifest - Write the repository manifest to
.git-sshripped/manifest.toml.