Crate git_sshripped_repository

Crate git_sshripped_repository 

Functions

github_sources_file
install_git_filters
Install Git filter and diff configuration via git config --local.
install_gitattributes
Append filter/diff attribute lines to .gitattributes for the given patterns.
local_config_file
manifest_file
metadata_dir
read_github_sources
Read the GitHub source registry, returning a default if the file does not exist.
read_local_config
Read the local repository config, returning a default if the file does not exist.
read_manifest
Read the repository manifest from .git-sshripped/manifest.toml.
write_github_sources
Write the GitHub source registry to .git-sshripped/github-sources.toml.
write_local_config
Write the local repository config to .git-sshripped/config.toml.
write_manifest
Write the repository manifest to .git-sshripped/manifest.toml.