Functions
- github_
sources_ file - install_
git_ filters - Install Git filter and diff configuration via
git config --local. - install_
gitattributes - Append filter/diff attribute lines to
.gitattributesfor the given patterns. - local_
config_ file - manifest_
file - metadata_
dir - read_
github_ sources - Read the GitHub source registry, returning a default if the file does not exist.
- read_
local_ config - Read the local repository config, returning a default if the file does not exist.
- read_
manifest - Read the repository manifest from
.git-sshripped/manifest.toml. - write_
github_ sources - Write the GitHub source registry to
.git-sshripped/github-sources.toml. - write_
local_ config - Write the local repository config to
.git-sshripped/config.toml. - write_
manifest - Write the repository manifest to
.git-sshripped/manifest.toml.