pub fn write_agent_wrap(
common_dir: &Path,
wrapped: &AgentWrappedKey,
) -> Result<()>Expand description
Write an agent-wrapped key file.
Errors
Returns an error if the directory cannot be created, the file cannot be serialized, or the file cannot be written.