pub fn write_github_sources(
repo_root: &Path,
registry: &GithubSourceRegistry,
) -> Result<()>Expand description
Write the GitHub source registry to .git-sshripped/github-sources.toml.
Errors
Returns an error if the metadata directory cannot be created, the registry cannot be serialized, or the file cannot be written.